class LabLayoutsController < ApplicationController
  model_data_store(LabLayout)

  def before_set_target
    @models.eager_load(:lab_layout_components)
  end

  def before_set_targets
    @models.eager_load(:lab_layout_components)
  end

  def save
    # Because the layout can contain image, it is passed in via form data which has to be stringified
    data = JSON.parse(params["layout"], symbolize_names: true)
    is_new = data[:id] == -1

    @model = if is_new
      LabLayout.new
    else
      LabLayout.eager_load(:lab_layout_components).find_by_id(data[:id])
    end
    return render json: {error: "Layout does not exist."}, status: 404 if @model.nil?

    @model.assign_attributes({name: data[:name]})
    @model.update_components(data[:components], params)

    @model.updated_at = Time.now # update the update to reflect component changes

    if @model.save
      ActionCable.server.broadcast "everything", {
        model: JSON.parse(@model.to_json),
        class: @model.broadcast_class_name,
        action: is_new ? :create : :update,
        timestamp: Time.now.to_i
      }
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end
end
