import * as React from "react";
import {observer} from "mobx-react-lite";
import {ColorPicker} from 'material-ui-color';
import {isArrayLike} from "@rx-suite/data";
import {makeStyles} from "@material-ui/core/styles";
import {useReadonlyContext} from "@rx-suite/ui";
import {DashboardComponentModel} from "../../../../stores/DashboardComponentStore";
import {Annotation} from "../../../../stores/Types";

const useStyles = makeStyles(() => ({
    wrapper: {
        display: "flex",
        alignItems: 'center'
    }
}));

export type ColorTargetPickerProps = {
    component: DashboardComponentModel,
    annotation: Annotation,
    name: string
}


export const AnnotationColorPicker: React.FunctionComponent<ColorTargetPickerProps> = observer(({
                                                                                                    component,
                                                                                                    annotation,
                                                                                                    name,
                                                                                                }) => {
        const classes = useStyles();
        const readOnly = useReadonlyContext();
        const annotationColor = annotation.color;
        const [workingColor, setWorkingColor] = React.useState(annotationColor);
        React.useEffect(() => {
            setWorkingColor(annotationColor);
        }, [setWorkingColor, annotationColor])
        const handleColorChange = React.useCallback(newColor => {
            if (!readOnly) {
                if (newColor.error || (!(isArrayLike(newColor.raw) && (newColor.raw.length < 6)))) {
                    setWorkingColor(newColor.raw); // if the user types in a Hex code we need to allow partial entry.  If they click directly on the picker grid then raw will be an array of values that we can extract a complete hex from
                } else if (newColor.hex) {
                    const withHash = newColor.hex[0] === '#' ? newColor.hex : `#${newColor.hex}`;
                    setWorkingColor(withHash);
                    component.nestedAssignment(name, withHash);
                }
            }
        }, [component, setWorkingColor, name, readOnly]);
        return (
            <div className={classes.wrapper}>
                <ColorPicker value={workingColor} onChange={handleColorChange} disableAlpha hideTextfield/>
            </div>
        );
    }
);