import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../../stores/DashboardComponentStore";
import {SelectField, useReadonlyContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";

export type StrokeCurveSelectProps = {
    component: DashboardComponentModel
}

export const StrokeCurveSelect: React.FunctionComponent<StrokeCurveSelectProps> = observer(({component}) => {
    const readOnly = useReadonlyContext();
    const label = t`Curve Type`;
    return <SelectField label={label}
                        name={`display_options.line.stroke.curve`}
                        value={component.viewModel.display_options?.line?.stroke?.curve || component.defaultCurve}
                        disabled={readOnly}
                        onChange={component.handleSelectChange}
                        options={[
                            {label: t`Smooth`, value: 'smooth'},
                            {label: t`Straight`, value: 'straight'},
                            {label: t`Step`, value: 'stepline'},
                        ]}
                        hint={{
                            title: label,
                            text: t`How to link the points together`
                        }}
    />

});