import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {DashboardComponentTable} from "./DashboardComponentTable";
import {ErrorBoundary} from "@rx-suite/ui"
import {DashboardComponentGauge} from "./DashboardComponentGauge";
import {DashboardComponentCounter} from "./DashboardComponentCounter";
import {DashboardComponentPieChart} from "./DashboardComponentPieChart";
import {DashboardComponentPolarAreaChart} from "./DashboardComponentPolarAreaChart";
import {DashboardComponentRadarChart} from "./DashboardComponentRadarChart";
import {DashboardComponentBarChart} from "./DashboardComponentBarChart";
import {DashboardComponentLineChart} from "./DashboardComponentLineChart";
import {DashboardComponentScatterChart} from "./DashboardComponentScatterChart";
import {DashboardComponentHeatmap} from "./DashboardComponentHeatmap";
import {DashboardComponentTreemap} from "./DashboardComponentTreemap";
import {DashboardComponentLabStatus} from "./DashboardComponentLabStatus";
import {DashboardComponentScoreCard} from "./DashboardComponentScoreCard";

export type DashboardComponentProps = {
    component: DashboardComponentModel
};

export const DashboardComponent: React.FunctionComponent<DashboardComponentProps> = observer(({component}) => {
    return <ErrorBoundary>
        {({
            pie: <DashboardComponentPieChart component={component}/>,
            polararea: <DashboardComponentPolarAreaChart component={component}/>,
            radar: <DashboardComponentRadarChart component={component}/>,
            bar: <DashboardComponentBarChart component={component}/>,
            line: <DashboardComponentLineChart component={component}/>,
            scatter: <DashboardComponentScatterChart component={component}/>,
            heatmap: <DashboardComponentHeatmap component={component}/>,
            treemap: <DashboardComponentTreemap component={component}/>,
            table: <DashboardComponentTable component={component}/>,
            score_card: <DashboardComponentScoreCard component={component}/>,
            gauge: <DashboardComponentGauge component={component}/>,
            counter: <DashboardComponentCounter component={component}/>,
            lab_status: <DashboardComponentLabStatus component={component}/>
        } as { [s: string]: JSX.Element })[component.viewModel.display_type] || null}
    </ErrorBoundary>;
});
