import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {LineChart} from "@rx-suite/ui";
import {useGraphOptions} from "../../../hooks/useGraphOptions";

export type DashboardComponentLineChartProps = {
    component: DashboardComponentModel
};

export const DashboardComponentLineChart: React.FunctionComponent<DashboardComponentLineChartProps> = observer(({component}) => {
    const series = component.viewModel.data.series || [];
    const options = useGraphOptions(component);

    if (component.isNew) {
        const fakeSeries = [{
            data: [Math.floor(Math.random() * 10), Math.floor(Math.random() * 10), Math.floor(Math.random() * 10)].map((v, i) => ({
                x: i + 1,
                y: v
            }))
        }];
        return <LineChart series={fakeSeries}
                          options={{
                              ...options,
                              colors: ['#DCDCDC']
                          }}
        />;
    } else {
        return <LineChart series={series}
                          options={options}
        />;
    }
});
