import {AppBar, Dialog, DialogContent, IconButton, Slide, Toolbar, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import * as React from "react";
import {DashboardStore} from "../../stores/DashboardStore";
import {observer} from "mobx-react-lite";
import {when} from "mobx";
import {DashboardGroupModel} from "../../stores/DashboardGroupStore";
import {DashboardForm} from "../../pages/dashboards/DashboardForm";
import {makeStyles} from "@material-ui/core/styles";
import {Close} from '@material-ui/icons';

export type NestedDashboardFormProps = {
    group: DashboardGroupModel,
    open: boolean,
    setOpen: ((newOpen: boolean) => void)
};

const useStyles = makeStyles((theme) => ({
    appBar: {
        position: 'relative',
    },
    title: {
        marginLeft: theme.spacing(2),
        flex: 1,
    },
}));

const Transition = React.forwardRef(function Transition(props, ref) {
    return <Slide direction="up" ref={ref} {...props} />;
});

export const NestedDashboardForm: React.FunctionComponent<NestedDashboardFormProps> = observer(({
                                                                                                    group,
                                                                                                    open,
                                                                                                    setOpen
                                                                                                }) => {
    const classes = useStyles();
    const closeForm = React.useCallback(() => setOpen(false), [setOpen]);
    const afterSubmit = React.useCallback((e, resp) => {
        console.dir(resp);
        when(() => !!DashboardStore.get(resp.id), () => {
            group.addDashboard(DashboardStore.get(resp.id)!);
        })
        closeForm();
    }, [group, closeForm])
    return <Dialog open={open} onClose={closeForm} fullScreen TransitionComponent={Transition}>
        <AppBar className={classes.appBar}>
            <Toolbar>
                <IconButton edge="start" color="inherit" onClick={closeForm} aria-label="close">
                    <Close/>
                </IconButton>
                <Typography variant="h6" className={classes.title}>
                    {t`New Dashboard`}
                </Typography>
            </Toolbar>
        </AppBar>
        <DialogContent>
            {/*//make a new model for each opening*/}
            {open && <DashboardForm model={DashboardStore.createModel()} afterSubmit={afterSubmit}
                                    suppressRedirect/>}
        </DialogContent>
    </Dialog>
});