import * as React from 'react';
import {observer} from 'mobx-react-lite';
import {Grid, GridItem} from '@rx-suite/ui';
import {DashboardModel} from "../../stores/DashboardStore";
import {DashboardGridItem} from "./DashboardGridItem";
import {DashboardGroupHeader} from "../dashboard_groups/DashboardGroupHeader";
import {makeStyles} from "@material-ui/core/styles";

export type DashboardGridProps = {
    dashboard: DashboardModel,
    editMode?: boolean
}

const useStyles = makeStyles({
    headerWrapper: {
        padding: '0'
    }
});

export const DashboardGrid: React.FunctionComponent<DashboardGridProps> = observer(({dashboard, editMode}) => {
    const classes = useStyles();

    React.useEffect(() => {
        window.dispatchEvent(new Event('resize'));
        setTimeout(() => {
            window.dispatchEvent(new Event('resize'));
        }, 100);
        setTimeout(() => {
            window.dispatchEvent(new Event('resize'));
        }, 500);
    }, []); // try to force the charts to auto-size to the correct layout

    return <>

        <Grid onLayoutChange={dashboard.handleLayoutChange} compactType={'vertical'}
              resizeHandles={editMode ? ['e', 'se', 's'] : []}>
            {dashboard.viewModel.header_enabled &&
            <GridItem key={'header'} id={'header'} x={0} y={0}
                      width={24} height={2} fixed={true}
                      component={'div'} className={classes.headerWrapper}>
                <DashboardGroupHeader dashboard={dashboard}/>
            </GridItem>
            }
            {dashboard.placements.map(p => (
                <GridItem key={p.getId()} id={p.getId().toString()} x={p.viewModel.x} y={p.viewModel.y}
                          width={p.viewModel.width} height={p.viewModel.height} fixed={!editMode}
                          component={'div'}
                          onDelete={editMode ? () => {
                              dashboard.removePlacement(p);
                          } : undefined}
                >
                    <DashboardGridItem key={p.getId()} placement={p} editMode={editMode}/>
                </GridItem>
            ))}
        </Grid>
    </>
});
